@@ -19,7 +19,6 @@
  * Foundation, 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
  */
 
-#include <wait.h>
 #include <unistd.h>
 #include <signal.h>
 #include <syslog.h>
@@ -28,6 +27,7 @@
 #include <stdio.h>
 #include <assert.h>
 #include <fnmatch.h>
+#include <sys/wait.h>
 #include <sys/types.h>
 #include <sys/time.h>
 #include <sys/stat.h>
@@ -94,7 +94,7 @@ static void sighandler_chld(int x) {
 	     (long)r,status);
     } else if (WEXITSTATUS(status)>12) {
       if (WEXITSTATUS(status)>24)
-	syslog(LOG_ERR,"call pid %ld exited with status %ld >24",
+	syslog(LOG_ERR,"call pid %ld exited with status %d >24",
 	       (long)r,WEXITSTATUS(status));
       checkstalepipes();
     }
