@@ -41,7 +41,6 @@
 #include <stdio.h>
 #include <stdarg.h>
 #include <unistd.h>
-#include <wait.h>
 #include <assert.h>
 #include <signal.h>
 #include <string.h>
@@ -52,6 +51,7 @@
 #include <grp.h>
 #include <ctype.h>
 #include <limits.h>
+#include <sys/wait.h>
 #include <sys/types.h>
 #include <sys/fcntl.h>
 #include <sys/stat.h>
